==> u%2B%2B_5.0.1.orig.tar.gz: u++-5.0.1/src/collection/example_Queue.cc <==
#include "uQueue.h"
#include "iostream.h"

class fred : public uColable {
  public:
    int i;
    fred( int p ) { i = p; }
};

class mary: public fred {
  public:
    mary( int i ) : fred(i) {}
};

main() {
    uQueue<fred> foo;
    uQueueGen<fred> foogen( foo );
    uQueue<mary> bar;
    uQueueGen<mary> bargen( bar );
    fred *f;
    mary *m;
    int i;

    // fred test

    for ( ; foogen >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	foo.uAdd( new fred( 2 * i ) );
    }

    for ( foogen.uOver(foo); foogen >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 9; i += 1 ) {
	foo.uDrop();
    }

    for ( foogen.uOver( foo ); foogen >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	foo.uAdd( new fred( 2 * i + 1 ) );
    }
    for ( foogen.uOver( foo ); foogen >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";

    // mary test

    for ( ; bargen >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	bar.uAdd( new mary( 2 * i ) );
    }

    for ( bargen.uOver( bar ); bargen >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 9; i += 1 ) {
	bar.uDrop();
    }

    for ( bargen.uOver( bar ); bargen >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	bar.uAdd( new mary( 2 * i + 1 ) );
    }
    for ( bargen.uOver( bar ); bargen >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
}

// Local Variables: //
// compile-command: "g++ example_Queue.cc" //
// End: //

==> u%2B%2B_5.3.0.orig.tar.gz: u++-5.3.0/src/collection/example_Queue.cc <==
#include "uQueue.h"
#include "iostream.h"

class fred : public uColable {
  public:
    int i;
    fred( int p ) { i = p; }
};

class mary: public fred {
  public:
    mary( int i ) : fred(i) {}
};

main() {
    uQueue<fred> foo;
    uQueueIter<fred> fooIter( foo );
    uQueue<mary> bar;
    uQueueIter<mary> barIter( bar );
    fred *f;
    mary *m;
    int i;

    // fred test

    for ( ; fooIter >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	foo.add( new fred( 2 * i ) );
    }

    for ( fooIter.over(foo); fooIter >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 9; i += 1 ) {
	foo.drop();
    }

    for ( fooIter.over( foo ); fooIter >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	foo.add( new fred( 2 * i + 1 ) );
    }
    for ( fooIter.over( foo ); fooIter >> f; ) {
	cout << f->i << " ";
    }
    cout << "\n";

    // mary test

    for ( ; barIter >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	bar.add( new mary( 2 * i ) );
    }

    for ( barIter.over( bar ); barIter >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 9; i += 1 ) {
	bar.drop();
    }

    for ( barIter.over( bar ); barIter >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
    
    for ( i = 0; i < 10; i += 1 ) {
	bar.add( new mary( 2 * i + 1 ) );
    }
    for ( barIter.over( bar ); barIter >> m; ) {
	cout << m->i << " ";
    }
    cout << "\n";
}

// Local Variables: //
// compile-command: "g++ example_Queue.cc" //
// End: //
